@@ -2,7 +2,7 @@
 /**
  * Nag external API interface.
  *
- * $Horde: nag/lib/api.php,v 1.100.10.42 2008/08/18 22:38:51 jan Exp $
+ * $Horde: nag/lib/api.php,v 1.100.10.46 2009/09/04 10:38:38 jan Exp $
  *
  * This file defines Nag's external API interface. Other applications can
  * interact with Nag through this API.
@@ -65,18 +65,18 @@ $_services['list'] = array(
 );
 
 $_services['listBy'] = array(
-    'args' => array('action' => 'string', 'timestamp' => 'int'),
+    'args' => array('action' => 'string', 'timestamp' => 'int', 'tasklist' => 'string'),
     'type' => '{urn:horde}stringArray',
 );
 
 $_services['getActionTimestamp'] = array(
-    'args' => array('uid' => 'string', 'timestamp' => 'int'),
+    'args' => array('uid' => 'string', 'action' => 'string', 'tasklist' => 'string'),
     'type' => 'int',
 );
 
 $_services['import'] = array(
     'args' => array('content' => 'string', 'contentType' => 'string', 'tasklist' => 'string'),
-    'type' => 'int',
+    'type' => 'string',
 );
 
 $_services['export'] = array(
@@ -1201,16 +1201,18 @@ function _nag_replace($uid, $content, $contentType)
             }
 
             $components = $iCal->getComponents();
-            switch (count($components)) {
-            case 0:
+            $component = null;
+            foreach ($components as $content) {
+                if (is_a($content, 'Horde_iCalendar_vtodo')) {
+                    if ($component !== null) {
+                        return PEAR::raiseError(_("Multiple iCalendar components found; only one vTodo is supported."));
+                    }
+                    $component = $content;
+                }
+
+            }
+            if ($component === null) {
                 return PEAR::raiseError(_("No iCalendar data was found."));
-
-            case 1:
-                $content = $components[0];
-                break;
-
-            default:
-                return PEAR::raiseError(_("Multiple iCalendar components found; only one vTodo is supported."));
             }
         }
 
